==> kjy-center-api-0.8.25-xt-1.0.16-20200420.061437-1-sources.jar: cn/com/duiba/kjy/api/dto/preInstall/PreInstallBatchDto.java <==
package cn.com.duiba.kjy.api.dto.preInstall;

import java.io.Serializable;
import java.util.Date;
import lombok.Data;

/**
 * 
 * @author kjj mybatis generator 
 * 2020-04-13
 */
@Data
public class PreInstallBatchDto implements Serializable {
    private static final long serialVersionUID = 15867560712673799L;

    /**
     *
     *主键ID
     * not null default = null
     */
    private Long id;

    /**
     *
     *预设类型：1:直播预设账号
     * not null default = null
     */
    private Integer preType;

    /**
     *
     *备注
     * max length = 200
     */
    private String remark;

    /**
     *
     *总数量
     * not null default = 0
     */
    private Integer totalCount;

    /**
     *
     *已激活数量
     * not null default = 0
     */
    private Integer activateCount;

    /**
     *
     *二维码链接
     * max length = 256
     */
    private String qrCode;

    /**
     *
     *状态：-1:删除  0：禁用  1:使用中 
     * not null default = 1
     */
    private Integer batchStatus;

    /**
     *
     *二维码有效期
     * not null default = null
     */
    private Date vipValidity;

    /**
     *
     *会员周期类型,1:天,2:月 3:年
     * not null default = null
     */
    private Integer vipPeriodType;

    /**
     *
     *会员周期数量
     * not null default = null
     */
    private Integer vipPeriodCount;

    /**
     *
     *用户版本
     * not null default = 2
     */
    private Integer userVersion;

    /**
     * 打款记录ID tb_serial_pay_record.id
     */
    private Long serialId;

    /**
     *
     *创建时间
     * not null default = CURRENT_TIMESTAMP
     */
    private Date gmtCreate;

    /**
     *
     *修改时间
     * not null default = CURRENT_TIMESTAMP
     */
    private Date gmtModified;
}

==> kjy-center-api-0.9.22-xt3-20200730.075818-1-sources.jar: cn/com/duiba/kjy/api/dto/preInstall/PreInstallBatchDto.java <==
package cn.com.duiba.kjy.api.dto.preInstall;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 *
 * @author kjj mybatis generator
 * 2020-04-13
 */
@Data
public class PreInstallBatchDto implements Serializable {
    private static final long serialVersionUID = 15867560712673799L;

    /**
     *
     *主键ID
     * not null default = null
     */
    private Long id;

    /**
     *
     *预设类型：1:直播预设账号
     * not null default = null
     */
    private Integer preType;

    /**
     *
     *备注
     * max length = 200
     */
    private String remark;

    /**
     *
     *总数量
     * not null default = 0
     */
    private Integer totalCount;

    /**
     *
     *已激活数量
     * not null default = 0
     */
    private Integer activateCount;

    /**
     *
     *二维码链接
     * max length = 256
     */
    private String qrCode;

    /**
     *
     *状态：-1:删除  0：禁用  1:使用中
     * not null default = 1
     */
    private Integer batchStatus;

    /**
     *
     *二维码有效期
     * not null default = null
     */
    private Date vipValidity;

    /**
     *
     *会员周期类型,1:天,2:月 3:年
     * not null default = null
     */
    private Integer vipPeriodType;

    /**
     *
     *会员周期数量
     * not null default = null
     */
    private Integer vipPeriodCount;

    /**
     *
     *用户版本
     * not null default = 2
     */
    private Integer userVersion;

    /**
     * 打款记录ID tb_serial_pay_record.id
     */
    private Long serialId;

    /**
     *
     *创建时间
     * not null default = CURRENT_TIMESTAMP
     */
    private Date gmtCreate;

    /**
     *
     *修改时间
     * not null default = CURRENT_TIMESTAMP
     */
    private Date gmtModified;

    /**
     * 绑定公司ID
     */
    private Long companyId;

    /**
     * 绑定团队的ID
     */
    private Long teamId;

    /**
     * 是否预设手机号
     * @see cn.com.duiba.kjy.api.enums.preInsatll.PrePhoneEnum
     */
    private Integer prePhone;
}
